==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/turtle/dialogs_de.lua <==

dialogId("zel-v-zelva0", "font_big", "Can you see it? This must be that telepathic turtle.")
dialogStr("Siehst du sie? Das muss die telepatische Schildkröte sein.")


dialogId("zel-v-zelva1", "font_big", "Yes, this is it. The telepathic turtle.")
dialogStr("Ja, das ist sie. Die telepatische Schildkröte.")


dialogId("zel-m-fotky0", "font_small", "Well, I don`t know. Judging from those photos, it could be it.")
dialogStr("Naja, ich weiß nicht. Nach den Fotos zu urteilen, könnte sie es sein.")


dialogId("zel-m-fotky1", "font_small", "I am not sure... what about those telepathic powers?")
dialogStr("Ich bin mir nicht sicher... was ist mit den telepatischen Fähigkeiten?")


dialogId("zel-v-zmistnosti0", "font_big", "In any case we have to get it out of the room.")
dialogStr("Auf jeden Fall müssen wir sie aus dem Raum bekommen.")


dialogId("zel-v-zmistnosti1", "font_big", "Let`s take out that turtle.")
dialogStr("Lass uns die Schildkröte rausbringen.")


dialogId("zel-m-coto0", "font_small", "What are you doing?")
dialogStr("Was tust du?")


dialogId("zel-m-coto1", "font_small", "What have you done?")
dialogStr("Was hast du getan?")


dialogId("zel-m-coto2", "font_small", "What is it supposed to mean?")
dialogStr("Was hat das zu bedeuten?")


dialogId("zel-v-coto0", "font_big", "Where are you swimming?")
dialogStr("Wohin schwimmst du?")


dialogId("zel-v-coto1", "font_big", "What should it mean?")
dialogStr("Was bedeutet das?")


dialogId("zel-v-coto2", "font_big", "What happened to you?")
dialogStr("Was ist mit dir passiert?")


dialogId("zel-m-nevim0", "font_small", "I don`t know...")
dialogStr("Ich weiß nicht...")


dialogId("zel-m-nevim1", "font_small", "I can`t realize...")
dialogStr("Ich begreife es nicht...")


dialogId("zel-v-nevim0", "font_big", "I don`t know what`s happening to me...")
dialogStr("Ich weiß nicht, was mit mir passiert...")


dialogId("zel-v-nevim1", "font_big", "I didn`t want to...")
dialogStr("Ich wollte nicht...")


dialogId("zel-v-cosedeje", "font_big", "What`s happening to us?")
dialogStr("Was passiert mit uns?")


dialogId("zel-m-cimtoje", "font_small", "What can it mean?")
dialogStr("Was kann es bedeuten?")


dialogId("zel-m-tazelva", "font_small", "This must be that turtle!")
dialogStr("Das muss diese Schildkröte sein!")


dialogId("zel-v-tazelva", "font_big", "This must be that turtle!")
dialogStr("Das muss diese Schildkröte sein!")


dialogId("zel-m-jasne", "font_small", "So there can be no doubts now - this is it. The one we are looking for!")
dialogStr("Dann gibt es jetzt keine Zweifel mehr - das ist sie. Die nach der wir suchen!")


dialogId("zel-v-pochyby", "font_big", "Doubtless, this is the turtle we are looking for!")
dialogStr("Das ist zweifellos die Schildkröte, nach der wir suchen!")


dialogId("zel-m-potvora0", "font_small", "That beast!")
dialogStr("Diese Bestie!")


dialogId("zel-m-potvora1", "font_small", "Stop it, you devil!")
dialogStr("Hör auf, du Teufel!")


dialogId("zel-v-stacit0", "font_big", "Enough is enough!")
dialogStr("Genug ist genug!")


dialogId("zel-v-stacit1", "font_big", "Are you enjoying yourself?")
dialogStr("Macht dir das Spaß?")


dialogId("zel-v-bizarni", "font_big", "So many bizarre shapes can only be found in a coral reef.")
dialogStr("So viele bizarre Formen gibt es nur in einem Korallenriff.")


dialogId("zel-m-priroda", "font_small", "These corals are Mother Nature`s wonders.")
dialogStr("Diese Korallen sind Wunder der Mutter Natur.")


dialogId("zel-v-tvary", "font_big", "Where do so many bizarre shapes come from?")
dialogStr("Woher kommen so viele bizarre Formen?")


dialogId("zel-m-jednoduse", "font_small", "It`s easy - designers create tricky problems and leave the drawing to the graphic artists.")
dialogStr("Das ist leicht - die Entwickler denken sich knifflige Probleme aus und überlassen das Malen den Künstlern.")


dialogId("zel-v-ukol", "font_big", "Our goal in this room is to get out that turtle.")
dialogStr("Unser Ziel in diesem Raum ist es, diese Schildkröte herauszubekommen.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/turtle/dialogs_de.lua <==

dialogId("zel-v-zelva0", "font_big", "Can you see it? This must be that telepathic turtle.")
dialogStr("Siehst du sie? Das muss die telepatische Schildkröte sein.")


dialogId("zel-v-zelva1", "font_big", "Yes, this is it. The telepathic turtle.")
dialogStr("Ja, das ist sie. Die telepatische Schildkröte.")


dialogId("zel-m-fotky0", "font_small", "Well, I don’t know. Judging from those photos, it could be it.")
dialogStr("Naja, ich weiß nicht. Nach den Fotos zu urteilen, könnte sie es sein.")


dialogId("zel-m-fotky1", "font_small", "I am not sure... what about those telepathic powers?")
dialogStr("Ich bin mir nicht sicher... was ist mit den telepatischen Fähigkeiten?")


dialogId("zel-v-zmistnosti0", "font_big", "In any case we have to get it out of the room.")
dialogStr("Auf jeden Fall müssen wir sie aus dem Raum bekommen.")


dialogId("zel-v-zmistnosti1", "font_big", "Let’s take out that turtle.")
dialogStr("Lass uns die Schildkröte rausbringen.")


dialogId("zel-m-coto0", "font_small", "What are you doing?")
dialogStr("Was tust du?")


dialogId("zel-m-coto1", "font_small", "What have you done?")
dialogStr("Was hast du getan?")


dialogId("zel-m-coto2", "font_small", "What is it supposed to mean?")
dialogStr("Was hat das zu bedeuten?")


dialogId("zel-v-coto0", "font_big", "Where are you swimming?")
dialogStr("Wohin schwimmst du?")


dialogId("zel-v-coto1", "font_big", "What should it mean?")
dialogStr("Was bedeutet das?")


dialogId("zel-v-coto2", "font_big", "What happened to you?")
dialogStr("Was ist mit dir passiert?")


dialogId("zel-m-nevim0", "font_small", "I don’t know...")
dialogStr("Ich weiß nicht...")


dialogId("zel-m-nevim1", "font_small", "I can’t realize...")
dialogStr("Ich begreife es nicht...")


dialogId("zel-v-nevim0", "font_big", "I don’t know what’s happening to me...")
dialogStr("Ich weiß nicht, was mit mir passiert...")


dialogId("zel-v-nevim1", "font_big", "I didn’t want to...")
dialogStr("Ich wollte nicht...")


dialogId("zel-v-cosedeje", "font_big", "What’s happening to us?")
dialogStr("Was passiert mit uns?")


dialogId("zel-m-cimtoje", "font_small", "What can it mean?")
dialogStr("Was kann es bedeuten?")


dialogId("zel-m-tazelva", "font_small", "This must be that turtle!")
dialogStr("Das muss diese Schildkröte sein!")


dialogId("zel-v-tazelva", "font_big", "This must be that turtle!")
dialogStr("Das muss diese Schildkröte sein!")


dialogId("zel-m-jasne", "font_small", "So there can be no doubts now - this is it. The one we are looking for!")
dialogStr("Dann gibt es jetzt keine Zweifel mehr - das ist sie. Die nach der wir suchen!")


dialogId("zel-v-pochyby", "font_big", "Doubtless, this is the turtle we are looking for!")
dialogStr("Das ist zweifellos die Schildkröte, nach der wir suchen!")


dialogId("zel-m-potvora0", "font_small", "That beast!")
dialogStr("Diese Bestie!")


dialogId("zel-m-potvora1", "font_small", "Stop it, you devil!")
dialogStr("Hör auf, du Teufel!")


dialogId("zel-v-stacit0", "font_big", "Enough is enough!")
dialogStr("Genug ist genug!")


dialogId("zel-v-stacit1", "font_big", "Are you enjoying yourself?")
dialogStr("Macht dir das Spaß?")


dialogId("zel-v-bizarni", "font_big", "So many bizarre shapes can only be found in a coral reef.")
dialogStr("So viele bizarre Formen gibt es nur in einem Korallenriff.")


dialogId("zel-m-priroda", "font_small", "These corals are Mother Nature’s wonders.")
dialogStr("Diese Korallen sind Wunder der Mutter Natur.")


dialogId("zel-v-tvary", "font_big", "Where do so many bizarre shapes come from?")
dialogStr("Woher kommen so viele bizarre Formen?")


dialogId("zel-m-jednoduse", "font_small", "It’s easy - designers create tricky problems and leave the drawing to the graphic artists.")
dialogStr("Das ist leicht - die Entwickler denken sich knifflige Probleme aus und überlassen das Malen den Künstlern.")


dialogId("zel-v-ukol", "font_big", "Our goal in this room is to get out that turtle.")
dialogStr("Unser Ziel in diesem Raum ist es, diese Schildkröte herauszubekommen.")
